@@ -328,7 +328,7 @@ file_get_checksum_if_exists (GChecksumType   checksum_type,
 	GError *local_error = NULL;
 	gssize rsize;
 	guchar buffer[1024];
-	gboolean stop;
+	gboolean stop = FALSE;
 
 	file = g_file_new_for_path (path);
 	stream = g_file_read (file, NULL, &local_error);
@@ -883,7 +883,7 @@ get_heuristic (MediaArtType   type,
 						g_debug ("symlink('%s' --> '%s'), %s",
 						         album_art_file_path,
 						         target,
-						         g_strerror (errno));
+						         !retval ? g_strerror (errno) : "no error given");
 					} else {
 						GFile *art_file;
 						GFile *target_file;
@@ -944,7 +944,7 @@ get_heuristic (MediaArtType   type,
 
 						g_debug ("symlink('%s' --> '%s'), %s",
 						         album_art_file_path, target,
-						         g_strerror (errno));
+						         !retval ? g_strerror (errno) : "no error given");
 					}
 
 					g_object_unref (album_art_file);
@@ -1032,7 +1032,6 @@ media_art_set (const unsigned char  *buffer,
 	gboolean retval = FALSE;
 
 	g_return_val_if_fail (type > MEDIA_ART_NONE && type < MEDIA_ART_TYPE_COUNT, FALSE);
-	g_return_val_if_fail (artist != NULL, FALSE);
 	g_return_val_if_fail (title != NULL, FALSE);
 
 	/* What we do here:
@@ -1610,7 +1609,7 @@ process_thread (GTask        *task,
  * @related_file: File related to the media art
  * @buffer: (array length=len)(allow-none): a buffer containing @file data, or %NULL
  * @len: length of @buffer, or 0
- * @mime: MIME type of @buffer, or %NULL
+ * @mime: (allow-none): MIME type of @buffer, or %NULL
  * @artist: (allow-none): The artist name @file or %NULL
  * @title: (allow-none): The title for @file or %NULL
  * @cancellable: (allow-none): optional #GCancellable object, %NULL to
